@@ -13,6 +13,8 @@ from .conf import product_list
 import pytest_html
 from pytest_html import extras
 
+report_path = None
+report_name = None
 
 @pytest.hookimpl(hookwrapper=True)
 def pytest_runtest_makereport(item, call):
@@ -36,7 +38,8 @@ def pytest_runtest_makereport(item, call):
             if item.funcargs['test_mobile_obj'].screenshot_counter > 0:  # Handle non-breakable but script didn't handle fail case, therefore whole testcase will pass
                 f_name = item.funcargs['test_mobile_obj'].gif_file_name
         if f_name:
-            extra.append(extras.image(f_name, mime_type='image/gif', extension='gif'))
+            relative_path = os.path.relpath(f_name)
+            extra.append(extras.image(relative_path, mime_type='image/gif', extension='gif'))
         report.extra = extra
 
 @pytest.fixture
@@ -61,6 +64,10 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         test_obj.product = product
         test_obj.browser = browser
         test_obj.xlsx_config = xlsx_config
+        global report_path
+        global report_name
+        test_obj.report_name = report_name
+        test_obj.report_path = report_path
         # Setup and register a driver
         test_obj.register_driver(remote_flag, os_name, os_version, browser, browser_version, remote_project_name,
                                  remote_build_name, wdm)
@@ -128,6 +135,10 @@ def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package,
         test_mobile_obj.wdm = wdm
         test_mobile_obj.set_calling_module(testname)
         test_mobile_obj.xlsx_config = xlsx_config
+        global report_path
+        global report_name
+        test_mobile_obj.report_name = report_name
+        test_mobile_obj.report_path = report_path
         # Setup and register a driver
         test_mobile_obj.register_driver(mobile_os_name, mobile_os_version, device_name, app_package, app_activity,
                                         remote_flag, device_flag, app_name, app_path, ud_id, org_id, signing_id,
@@ -230,9 +241,9 @@ def cases(request, product, testID):
 
     name = request.config.getoption("--xlsx")
     sheet = "Context"
-    xlsx_path_app = "././conf/app/" + product + '/' + name
-    xlsx_path_web = "././conf/web/" + product + '/' + name
-    xlsx_path_rwd = "././conf/rwd/" + product + '/' + name
+    xlsx_path_app = "././conf/app/" + product + '/TestData/' + name
+    xlsx_path_web = "././conf/web/" + product + '/TestData/' + name
+    xlsx_path_rwd = "././conf/rwd/" + product + '/TestData/' + name
 
     if os.path.exists(xlsx_path_app):
         file_path = xlsx_path_app
@@ -241,7 +252,7 @@ def cases(request, product, testID):
     elif os.path.exists(xlsx_path_rwd):
         file_path = xlsx_path_rwd
     else:
-        raise ValueError("File not found in either ././conf/app or ././conf/web directories.")
+        raise ValueError("File not found in either ././conf/app/[product]/TestData or ././conf/web[product]/TestData directories.")
 
     df = pd.read_excel(file_path, sheet_name=sheet, dtype=str,
                        usecols=lambda x: 'Remark' not in x)
@@ -293,6 +304,10 @@ def pytest_configure(config):
     filename = 'report_' + datetime.now().strftime(
         "%Y%m%d_%H%M%S") + '_' + config.known_args_namespace.keyword + ".html"  # report_YYYYMMDD_HHMMSS_[target].html
     path = os.path.join(config.rootdir, 'reports', filename)
+    global report_path
+    global report_name
+    report_path = os.path.join(config.rootdir, 'reports')
+    report_name = 'report_' + datetime.now().strftime("%Y%m%d_%H%M%S") + '_' + config.known_args_namespace.keyword
     if html_report_conf.gen_report:
         config.option.htmlpath = path
 
