@@ -5,6 +5,7 @@ import os
 from inspect import getfullargspec
 import traceback
 import pytest_html
+import time
 
 
 class Wrapit():
@@ -64,6 +65,8 @@ class Wrapit():
         def wrapper(test_obj, product, cases, extra, testID, *args, **kwargs):
             try:
                 result = func(test_obj, product, cases, extra, testID, *args, **kwargs)
+                test_obj.write("Finish test")
+                test_obj.write('Script duration: %d seconds\n' % (int(time.time() - test_obj.start_time)))
                 test_obj.gif_file_name = test_obj.write_test_summary()
             except Exception as e:
                 print("Exception when trying to run test: %s" % __file__)
@@ -89,6 +92,8 @@ class Wrapit():
         def wrapper(test_obj, product, poc_cases, extra, testID, *args, **kwargs):
             try:
                 result = func(test_obj, product, poc_cases, extra, testID, *args, **kwargs)
+                test_obj.write("Finish test")
+                test_obj.write('Script duration: %d seconds\n' % (int(time.time() - test_obj.start_time)))
                 test_obj.gif_file_name = test_obj.write_test_summary()
             except Exception as e:
                 print("Exception when trying to run test: %s" % __file__)
@@ -114,6 +119,8 @@ class Wrapit():
         def wrapper(test_mobile_obj, product, cases, extra, testID, *args, **kwargs):
             try:
                 result = func(test_mobile_obj, product, cases, extra, testID, *args, **kwargs)
+                test_mobile_obj.write("Finish test")
+                test_mobile_obj.write('Script duration: %d seconds\n' % (int(time.time() - test_mobile_obj.start_time)))
                 test_mobile_obj.gif_file_name = test_mobile_obj.write_test_summary()
             except Exception as e:
                 print("Exception when trying to run test: %s" % __file__)
